==> nextcloud-30.0.10.tgz: nextcloud/apps/notifications/l10n/da.js <==
OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Vi ønsker at blive ved med at tilbyde vores push notifikationstjeneste gratis, men et stort antal af brugere vil overbelaste vores infrastruktur. Af denne grund er vi nødt til at ratebegrænse brugen af ​​push-meddelelser. Hvis du har brug for denne funktion, kan du overveje at bruge Nextcloud Enterprise.",
    "User not found" : "Bruger ikke fundet",
    "An unexpected error occurred, ask your administration to check the logs." : "Der opstod en uventet fejl. Bed din administration om at tjekke loggene.",
    "Hello %s" : "Hej %s",
    "Hello %s," : "Hej %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Ny meddelelse vedr %s","%n nye meddelelser vedr %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Du har en ny notifikation for %s","Du har %n nye notifikationer vedr %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Du kan ændre hyppigheden af disse e-mails eller deaktivere dem i <a href=\"%s\">indstillinger</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Du kan ændre hyppigheden af disse e-mails eller deaktivere dem i indstillingerne: %s",
    "Admin notifications" : "Administrator notifikationer",
    "Notifications" : "Notifikationer",
    "Push notifications - Fair use policy" : "Push-notifikationer - Politik for rimelig brug",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH sponsorerer en gratis gateway push-notifikationer for private brugere. For at sikre god service begrænser gatewayen antallet af notifikationer pr. server, og grænsen blev nået for denne server. For virksomhedsbrugere er en mere skalerbar gateway tilgængelig.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Denne app giver en backend og frontend til notifikations-API'en, der er tilgængelig i Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Denne app giver en backend og frontend til notifikations-API'en, der er tilgængelig i Nextcloud.\nAPI'en bruges af andre apps til at underrette brugere i web-UI og synkronisere klienter om forskellige ting. Nogle eksempler er:\n\n📬 Sammenkoblet fildeling: Du har modtaget en ny fjerndeling\n\n📑 Kommentarer: En anden bruger nævnte dig i en kommentar til en fil\n\n🚢 Opdateringsmeddelelse: Tilgængelig opdatering til en app eller selve nextcloud\n\n📣 Meddelelsescenter: En meddelelse blev sendt af en administrator",
    "Failed to perform action" : "Mislykkedes at udføre handling",
    "seconds ago" : "få sekunder siden",
    "Failed to dismiss notification" : "Kunne ikke fjerne notifikation",
    "Dismiss" : "Afvis",
    "Contact Nextcloud GmbH" : "Kontakt Nextcloud GmbH",
    "in {path}" : "i {path}",
    "Requesting browser permissions to show notifications" : "Anmoder om browsertilladelser til at vise meddelelser",
    "Push notifications might be unreliable" : "Push-meddelelser kan være upålidelige",
    "No notifications" : "Ingen notifikationer",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH sponsorerer en gratis push-notifikationsgateway til private brugere. For at sikre god service begrænser gatewayen antallet af push-beskeder pr. server. For virksomhedsbrugere er en mere skalerbar gateway tilgængelig. Kontakt Nextcloud GmbH for mere information.",
    "Failed to dismiss all notifications" : "Kunne ikke afvise alle underretninger",
    "Dismiss all notifications" : "Afvis alle underretninger",
    "Never" : "Aldrig",
    "1 hour" : "1 time",
    "3 hours" : "3 timer",
    "1 day" : "1 dag",
    "1 week" : "1 uge",
    "Your settings have been updated." : "Dine indstillinger er blevet opdateret.",
    "An error occurred while updating your settings." : "Der opstod en fejl under opdatering af dine indstillinger.",
    "Notifications defaults" : "Standardindstillinger for meddelelser",
    "Configure the default notification settings for new users" : "Konfigurer standardmeddelelsesindstillingerne for nye brugere",
    "Send email reminders about unhandled notifications after:" : "Send e-mail-påmindelser om ubehandlede meddelelser efter:",
    "Play sound when a new notification arrives" : "Afspil lyd, når der kommer en ny notifikation",
    "Play sound when a call started (requires Nextcloud Talk)" : "Afspil lyd, når et opkald startede (kræver Nextcloud Snak)",
    "None" : "Ingen",
    "You need to set up your email address before you can receive notification emails." : "Du skal konfigurere din e-mailadresse, før du kan modtage notifikations-e-mails.",
    "Also repeat sound on a secondary speaker" : "Gentag lyd på sekundær højtaler",
    "Selection of the speaker device is currently not supported by Safari" : "Valg af lydenhed er ikke muligt i Safari",
    "Select a device" : "Vælg en enhed"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.14.tgz: nextcloud/apps/notifications/l10n/da.js <==
OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Vi ønsker at blive ved med at tilbyde vores push notifikationstjeneste gratis, men et stort antal af brugere vil overbelaste vores infrastruktur. Af denne grund er vi nødt til at ratebegrænse brugen af ​​push-meddelelser. Hvis du har brug for denne funktion, kan du overveje at bruge Nextcloud Enterprise.",
    "User not found" : "Bruger ikke fundet",
    "An unexpected error occurred, ask your administration to check the logs." : "Der opstod en uventet fejl. Bed din administration om at tjekke loggene.",
    "Hello %s" : "Hej %s",
    "Hello %s," : "Hej %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Ny meddelelse vedr %s","%n nye meddelelser vedr %s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Du har en ny notifikation for %s","Du har %n nye notifikationer vedr %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Du kan ændre hyppigheden af disse e-mails eller deaktivere dem i <a href=\"%s\">indstillinger</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Du kan ændre hyppigheden af disse e-mails eller deaktivere dem i indstillingerne: %s",
    "Admin notifications" : "Administrator notifikationer",
    "Notifications" : "Notifikationer",
    "Push notifications - Fair use policy" : "Push-notifikationer - Politik for rimelig brug",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH sponsorerer en gratis gateway push-notifikationer for private brugere. For at sikre god service begrænser gatewayen antallet af notifikationer pr. server, og grænsen blev nået for denne server. For virksomhedsbrugere er en mere skalerbar gateway tilgængelig.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Denne app giver en backend og frontend til notifikations-API'en, der er tilgængelig i Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Denne app giver en backend og frontend til notifikations-API'en, der er tilgængelig i Nextcloud.\nAPI'en bruges af andre apps til at underrette brugere i web-UI og synkronisere klienter om forskellige ting. Nogle eksempler er:\n\n📬 Sammenkoblet fildeling: Du har modtaget en ny fjerndeling\n\n📑 Kommentarer: En anden bruger nævnte dig i en kommentar til en fil\n\n🚢 Opdateringsmeddelelse: Tilgængelig opdatering til en app eller selve nextcloud\n\n📣 Meddelelsescenter: En meddelelse blev sendt af en administrator",
    "Failed to perform action" : "Mislykkedes at udføre handling",
    "Failed to dismiss notification" : "Kunne ikke fjerne notifikation",
    "Dismiss" : "Afvis",
    "Contact Nextcloud GmbH" : "Kontakt Nextcloud GmbH",
    "in {path}" : "i {path}",
    "Push notifications might be unreliable" : "Push-meddelelser kan være upålidelige",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH sponsorerer en gratis push-notifikationsgateway til private brugere. For at sikre god service begrænser gatewayen antallet af push-beskeder pr. server. For virksomhedsbrugere er en mere skalerbar gateway tilgængelig. Kontakt Nextcloud GmbH for mere information.",
    "Requesting browser permissions to show notifications" : "Anmoder om browsertilladelser til at vise meddelelser",
    "No notifications" : "Ingen notifikationer",
    "Failed to dismiss all notifications" : "Kunne ikke afvise alle underretninger",
    "Dismiss all notifications" : "Afvis alle underretninger",
    "Never" : "Aldrig",
    "1 hour" : "1 time",
    "3 hours" : "3 timer",
    "1 day" : "1 dag",
    "1 week" : "1 uge",
    "Your settings have been updated." : "Dine indstillinger er blevet opdateret.",
    "An error occurred while updating your settings." : "Der opstod en fejl under opdatering af dine indstillinger.",
    "Notifications defaults" : "Standardindstillinger for meddelelser",
    "Configure the default notification settings for new users" : "Konfigurer standardmeddelelsesindstillingerne for nye brugere",
    "Send email reminders about unhandled notifications after:" : "Send e-mail-påmindelser om ubehandlede meddelelser efter:",
    "Play sound when a new notification arrives" : "Afspil lyd, når der kommer en ny notifikation",
    "Play sound when a call started (requires Nextcloud Talk)" : "Afspil lyd, når et opkald startede (kræver Nextcloud Snak)",
    "None" : "Ingen",
    "You need to set up your email address before you can receive notification emails." : "Du skal konfigurere din e-mailadresse, før du kan modtage notifikations-e-mails.",
    "Also repeat sound on a secondary speaker" : "Gentag lyd på sekundær højtaler",
    "Selection of the speaker device is currently not supported by Safari" : "Valg af lydenhed er ikke muligt i Safari",
    "Select a device" : "Vælg en enhed",
    "seconds ago" : "få sekunder siden"
},
"nplurals=2; plural=(n != 1);");
